%-----------------------------------------------------------------------------%
% Copyright (C) 1997-1998, 2003 The University of Melbourne.
% Copyright (C) 2015, 2018 The Mercury team.
% This file is distributed under the terms specified in COPYING.LIB.
%-----------------------------------------------------------------------------%
%-----------------------------------------------------------------------------%

% mercury_opengl -- a Mercury binding for OpenGL.

:- module mercury_opengl.
:- interface.

:- import_module mglu.
:- import_module mogl.

